# guardianhub/constants/agent_contract.py

class ActivityRoles:
    """The Mandatory 'Top 10 for any Sovereign Specialist."""
    RECON = "conduct_reconnaissance"
    HISTORY = "retrieve_intelligence_history"
    TACTICAL = "analyze_tactical_context"
    PROPOSAL = "formulate_mission_proposal"
    INTERVENTION = "execute_direct_intervention"
    ATTAINMENT = "verify_objective_attainment"
    DEBRIEF = "summarize_intelligence_debrief"
    AAR = "commit_mission_after_action_report"
    COMPLETION = "transmit_mission_completion"
    SUPPORT = "recruit_specialist_support"